# mikrotik-manager
Central Management System for Mikrotik's RouterOS.

## Roadmap - DEV Stage
- [ ] Claim Repository & PyPI Package Name
- [ ] Project Structure Setup (FastAPI, SQLAlchemy, Alembic, etc.)
- [ ] Web Interface Setup (starlette-admin or nicegui)
- [ ] Database Integration (MariaDB or MongoDB)
- [ ] Management of Mikrotik Devices (CRUD operations)
- [ ] Async connection to Mikrotik Devices (via Worker see celery)
- [ ] Fetch basic information from Mikrotik Devices (hostname, model, serial number, firmware version, etc.)
- [ ] Display Mikrotik Devices in Admin Panel
- [ ] Trigger basic actions on Mikrotik Devices (reboot, backup configuration, etc.)
- [ ] Implement Global Task Scheduler for periodic tasks
- [ ] User Authentication and Authorization
- [ ] Logging and Monitoring

more features to be added...
